#include "ac33mx128_pcu.h"
#include "ac33mx128_scu.h"
#include "ac33mx128_gpio.h"
#include "ac33mx128_libcfg.h"

uint32_t msec;

// system default I/O setting
void PCU_Init(void);

/**********************************************************************
 * @brief		SysTick handler sub-routine (1ms)
 * @param[in]	None
 * @return 		None
 **********************************************************************/
void SysTick_Handler (void) 					// SysTick Interrupt Handler @ 1000Hz
{
	if(msec)msec--;
}

void mainloop(void)
{
	uint8_t tmp = 0;
#if 1	
	// Test Pin setting PD8
	PCU_ConfigureFunction(PCD, 8, PD8_MUX_PD8);
	PCU_SetDirection(PCD, 8, PUSH_PULL_OUTPUT);
	PCU_ConfigurePullup(PCD, 8, DISABLE);	
	GPIO_SetValue(PD, _BIT(8));
	
	// Test Pin setting PD9
	PCU_ConfigureFunction(PCD, 9, PD9_MUX_PD9);
	PCU_SetDirection(PCD, 9, PUSH_PULL_OUTPUT);
	PCU_ConfigurePullup(PCD, 9, DISABLE);
	GPIO_SetValue(PD, _BIT(9));

	SysTick_Config(SystemCoreClock/1000);  //1msec interrupt 
	
	__enable_irq();	
	
	while(1){
		msec = 500;
		while(msec);
		GPIO_ClearValue(PD,_BIT(8));
		msec = 500;
		while(msec);
		GPIO_SetValue(PD,_BIT(8));
		if (tmp&0x1)
			GPIO_SetValue(PD,_BIT(9));
		else 
			GPIO_ClearValue(PD,_BIT(9));
		if (++tmp == 8) tmp = 0;
	}
#else 
	// Test Pin setting PB8
	PCU_ConfigureFunction(PCB, 8, PB8_MUX_PB8);
	PCU_SetDirection(PCB, 8, PUSH_PULL_OUTPUT);
	PCU_ConfigurePullup(PCB, 8, DISABLE);	
	GPIO_SetValue(PB, _BIT(8));
	
	// Test Pin setting PD9
	PCU_ConfigureFunction(PCB, 9, PB9_MUX_PB9);
	PCU_SetDirection(PCB, 9, PUSH_PULL_OUTPUT);
	PCU_ConfigurePullup(PCB, 9, DISABLE);
	GPIO_SetValue(PB, _BIT(9));

	SysTick_Config(SystemCoreClock/1000);  //1msec interrupt 
	
	__enable_irq();	
	
	while(1){
		msec = 200;
		while(msec);
		GPIO_ClearValue(PB,_BIT(8));
		msec = 200;
		while(msec);
		GPIO_SetValue(PB,_BIT(8));
		if (tmp&0x1)
			GPIO_SetValue(PB,_BIT(9));
		else 
			GPIO_ClearValue(PB,_BIT(9));
		if (++tmp == 8) tmp = 0;
	}	
#endif
}

int main(void)
{
	SystemInit();
	PCU_Init(); // all port control setting  !!You have to set PORT function!!
	SCU_ClockInit(); // MCLK=72Mhz(PLL) setting 



	mainloop();
	
	return (0);
}


void PCU_Init(void)
{
//Peripheral Enable Register 1  0:Disable, 1:Enable	
	SCU->PER1=SCU->PER1  
	| (1<<11)   // GPIOD
	| (1<<10)   // GPIOC
	| (1<<9)   // GPIOB
	| (1<<8)   // GPIOA
		; 		
//Peripheral Clock Enable Register 1 0:Disable, 1:Enable	
	SCU->PCER1=SCU->PCER1
	| (1<<11)   // GPIOD
	| (1<<10)   // GPIOC
	| (1<<9)   // GPIOB
	| (1<<8)   // GPIOA
		; 	
	
 	PORT_ACCESS_EN();  // enable writing permittion of ALL PCU register

	PCA->MR = 0 // PinMux setting (00b,01b,10b,11b)
	| (0<<30)   // 0:PA15, 1:MISO0, 2:T7C, 3:AN15
	| (0<<28)   // 0:PA14, 1:MOSI0,            3:AN14
	| (0<<26)   // 0:PA13, 1:SCK0,              3:AN13
	| (0<<24)   // 0:PA12, 1:SS0, 2:AD2I,     3:AN12
	| (0<<22)   // 0:PA11, 1:TRACED2,        3:AN11
	| (0<<20)   // 0:PA10, 1:TRACED1, 2:AD2O, 3:AN10
	| (0<<18)   // 0:PA9,  1:TRACED0, 2:AD1O, 3:AN9
	| (0<<16)   // 0:PA8, 1:TRACECLK, 2:AD0O, 3:AN8
	| (0<<14)   // 0:PA7, 1:TRACED3, 2:T3O, 3:AN7_CREF1
	| (0<<12)   // 0:PA6,                     2:T2O, 3:AN6_CREF0
	| (0<<10)   // 0:PA5,                     2:T1O, 3:AN5
	| (0<<8)   // 0:PA4,                       2:T0O, 3:AN4
	| (0<<6)   // 0:PA3,                            3:AN3_CP3
	| (0<<4)   // 0:PA2,                            3:AN2_CP2	
	| (0<<2)   // 0:PA1,                            3:AN1_CP1	
	| (0<<0)   // 0:PA0,                            3:AN0_CP0		
		; 
	PCA->CR = 0 // 0xFFFFFFFF(reset value) Input, output, open drain, analog
	| (0<<30)   // P15 0:Push-pull output, 1:Open-drain output, 2:Input, 3:Analog
	| (0<<28)   // P14
	| (0<<26)   // P13
	| (0<<24)   // P12
	| (0<<22)   // P11
	| (0<<20)   // P10
	| (0<<18)   // P9
	| (0<<16)   // P8
	| (0<<14)   // P7
	| (0<<12)   // P6
	| (0<<10)   // P5
	| (0<<8)   // P4
	| (0<<6)   // P3
	| (0<<4)   // P2
	| (0<<2)   // P1
	| (0<<0)   // P0	
		; 	
	PCA->PCR = 0 // pullup (0,1)
	| (0<<15)   // P15 0:Disable pull-up resistor, 1:Enable pull-up resister
	| (0<<14)   // P14
	| (0<<13)   // P13
	| (0<<12)   // P12
	| (0<<11)   // P11
	| (0<<10)   // P10
	| (0<<9)   // P9
	| (0<<8)   // P8
	| (0<<7)   // P7
	| (0<<6)   // P6
	| (0<<5)   // P5
	| (0<<4)   // P4
	| (0<<3)   // P3
	| (0<<2)   // P2
	| (0<<1)   // P1
	| (0<<0)   // P0	
		; 		
	
	
	PCB->MR = 0 // PinMux setting (00b,01b,10b,11b)
	| (0<<30)   // 0:PB15, 1:MP1WL
	| (0<<28)   // 0:PB14, 1:MP1WH
	| (0<<26)   // 0:PB13, 1:MP1VL
	| (0<<24)   // 0:PB12, 1:MP1VH
	| (0<<22)   // 0:PB11, 1:MP1UL
	| (0<<20)   // 0:PB10, 1:MP1UH
	| (0<<18)   // 0:PB9,  1:OVIN1, 2:TXD3
	| (0<<16)   // 0:PB8, 1:PRTIN1, 2:RXD3
	| (0<<14)   // 0:PB7, 1:OVIN0, 2:STBYO
	| (0<<12)   // 0:PB6, 1:PRTIN0, 2:WDTO
	| (0<<10)   // 0:PB5, 1:MP0WL, 2:T9O
	| (0<<8)   // 0:PB4, 1:MP0WH, 2:T9C
	| (0<<6)   // 0:PB3, 1:MP0VL
	| (0<<4)   // 0:PB2, 1:MP0VH
	| (0<<2)   // 0:PB1, 1:MP0UL
	| (0<<0)   // 0:PB0, 1:MP0UH 
		;	
	PCB->CR = 0   // 0xFFFFFFFF(reset value) Input, output, open drain, analog
	| (0<<30)   // P15 0:Push-pull output, 1:Open-drain output, 2:Input, 3:Analog
	| (0<<28)   // P14
	| (0<<26)   // P13
	| (0<<24)   // P12
	| (0<<22)   // P11
	| (0<<20)   // P10
	| (0<<18)   // P9
	| (0<<16)   // P8
	| (0<<14)   // P7
	| (0<<12)   // P6
	| (0<<10)   // P5
	| (0<<8)   // P4
	| (0<<6)   // P3
	| (0<<4)   // P2
	| (0<<2)   // P1
	| (0<<0)   // P0	
		; 	
	PCB->PCR = 0 // pullup (0,1)
	| (0<<15)   // P15 0:Disable pull-up resistor, 1:Enable pull-up resister
	| (0<<14)   // P14
	| (0<<13)   // P13
	| (0<<12)   // P12
	| (0<<11)   // P11
	| (0<<10)   // P10
	| (0<<9)   // P9
	| (0<<8)   // P8
	| (0<<7)   // P7
	| (0<<6)   // P6
	| (0<<5)   // P5
	| (0<<4)   // P4
	| (0<<3)   // P3
	| (0<<2)   // P2
	| (0<<1)   // P1
	| (0<<0)   // P0	
		; 
	
	PCC->MR = 0 //0x00100155(reset value) // PinMux setting (00b,01b,10b,11b)
	| (1<<30)   // 0:PC15, 1:TXD0, 2:MOSI0
	| (1<<28)   // 0:PC14, 1:RXD0, 2:MISO0, 3:VMARGIN
	| (1<<26)   // 0:PC13, 1:XOUT
	| (1<<24)   // 0:PC12, 1:XIN
	| (0<<22)   // 0:PC11,            2:T8C
	| (1<<20)   // 0:PC10, 1:nRESET,
	| (0<<18)   // 0:PC9,  1:CLKO, 2:P8O
	| (0<<16)   // 0:PC8, 1:SDA0
	| (0<<14)   // 0:PC7, 1:SCL0, 2:T3C
	| (0<<12)   // 0:PC6, 1:TXD1, 2:T2C_PHZ
	| (0<<10)   // 0:PC5, 1:RXD1, 2:T1C_PHB
	| (1<<8)   // 0:PC4, 1:nTRST, 2:T0C_PHA
	| (1<<6)   // 0:PC3, 1:TDI
	| (1<<4)   // 0:PC2, 1:TDO_SWO
	| (1<<2)   // 0:PC1, 1:TMS_SWDIO
	| (1<<0)   // 0:PC0, 1:TCK_SWCLK 
		;		
	PCC->CR = 0   // 0xFFAFFE8A(reset value) Input, output, open drain, analog
	| (0<<30)   // P15 0:Push-pull output, 1:Open-drain output, 2:Input, 3:Analog
	| (2<<28)   // P14
	| (3<<26)   // P13  if XOUT, it must be Analog 
	| (3<<24)   // P12  if XIN, it must be Analog
	| (0<<22)   // P11
	| (2<<20)   // P10
	| (0<<18)   // P9
	| (0<<16)   // P8
	| (0<<14)   // P7
	| (0<<12)   // P6
	| (0<<10)   // P5
	| (2<<8)   // P4
	| (2<<6)   // P3
	| (2<<4)   // P2
	| (2<<2)   // P1
	| (2<<0)   // P0	
		; 	
	PCC->PCR = 0 // pullup (0,1)
	| (0<<15)   // P15 0:Disable pull-up resistor, 1:Enable pull-up resister
	| (0<<14)   // P14
	| (0<<13)   // P13
	| (0<<12)   // P12
	| (0<<11)   // P11
	| (0<<10)   // P10
	| (0<<9)   // P9
	| (0<<8)   // P8
	| (0<<7)   // P7
	| (0<<6)   // P6
	| (0<<5)   // P5
	| (0<<4)   // P4
	| (0<<3)   // P3
	| (0<<2)   // P2
	| (0<<1)   // P1
	| (0<<0)   // P0	
		; 

	PCD->MR = 0 // PinMux setting (00b,01b,10b,11b)
	| (0<<30)   // 0:PD15, 1:AD2EOC
	| (0<<28)   // 0:PD14, 1:AD2SOC
	| (0<<26)   // 0:PD13, 1:AD1EOC, 2:T3C
	| (0<<24)   // 0:PD12, 1:AD1SOC, 2:T2C_PHZ
	| (0<<22)   // 0:PD11, 1:AD0EOC, 2:T1C_PHB
	| (0<<20)   // 0:PD10, 1:AD0SOC, 2:T0C_PHA
	| (0<<18)   // 0:PD9,                     2:STBYO
	| (0<<16)   // 0:PD8,                     2:WDTO
	| (0<<14)   // 0:PD7, 1:RXD2, 2:AD1I
	| (0<<12)   // 0:PD6, 1:TXD2, 2:AD0I
	| (0<<10)   // 0:PD5, 1:SDA1
	| (0<<8)   // 0:PD4, 1:SCL1
	| (0<<6)   // 0:PD3, 1:MISO1
	| (0<<4)   // 0:PD2, 1:MOSI1
	| (0<<2)   // 0:PD1, 1:SCK1
	| (0<<0)   // 0:PD0, 1:SS1
		;		
	PCD->CR = 0   // 0xFFFFFFFF(reset value) Input, output, open drain, analog
	| (0<<30)   // P15 0:Push-pull output, 1:Open-drain output, 2:Input, 3:Analog
	| (0<<28)   // P14
	| (0<<26)   // P13
	| (0<<24)   // P12
	| (0<<22)   // P11
	| (0<<20)   // P10
	| (0<<18)   // P9
	| (0<<16)   // P8
	| (0<<14)   // P7
	| (0<<12)   // P6
	| (0<<10)   // P5
	| (0<<8)   // P4
	| (0<<6)   // P3
	| (0<<4)   // P2
	| (0<<2)   // P1
	| (0<<0)   // P0	
		; 	
	PCD->PCR = 0 // pullup (0,1)
	| (0<<15)   // P15 0:Disable pull-up resistor, 1:Enable pull-up resister
	| (0<<14)   // P14
	| (0<<13)   // P13
	| (0<<12)   // P12
	| (0<<11)   // P11
	| (0<<10)   // P10
	| (0<<9)   // P9
	| (0<<8)   // P8
	| (0<<7)   // P7
	| (0<<6)   // P6
	| (0<<5)   // P5
	| (0<<4)   // P4
	| (0<<3)   // P3
	| (0<<2)   // P2
	| (0<<1)   // P1
	| (0<<0)   // P0	
		; 
	PORT_ACCESS_DIS();  // disable writing permittion of ALL PCU register 	
}
